@@ -12,9 +12,9 @@ OC.L10N.register(
     "Open »%s«" : "Abrir «%s»",
     "Cheers!" : "¡Saludos!",
     "Upcoming events" : "Eventos próximos",
-    "More events" : "Más eventos",
     "No more events today" : "Nun hai más eventos pa güei",
     "No upcoming events" : "Nun hai eventos próximos",
+    "More events" : "Más eventos",
     "%1$s with %2$s" : "%1$s con %2$s",
     "Calendar" : "Calendariu",
     "New booking {booking}" : "Reserva nueva «{booking}»",
@@ -177,6 +177,7 @@ OC.L10N.register(
     "Weekdays" : "Díes de la selmana",
     "Update" : "Anovar",
     "Your email address" : "La to direición de corréu electrónicu",
+    "Back" : "Atrás",
     "Notification" : "Avisu",
     "Email" : "Corréu electrónicu",
     "Audio notification" : "Avisu d'audiu",
@@ -191,12 +192,12 @@ OC.L10N.register(
     "_week_::_weeks_" : ["selmana","selmanes"],
     "Delete file" : "Desaniciar el ficheru",
     "Confirmation" : "Confirmación",
-    "Invitation accepted" : "Invitación aceptada",
     "Available" : "Disponible",
+    "Invitation accepted" : "Invitación aceptada",
     "Not available" : "Nun ta disponible",
     "Invitation declined" : "Invitación refugada",
-    "Checking availability" : "Comprobando la disponibilidá",
     "Awaiting response" : "Esperando pola rempuesta",
+    "Checking availability" : "Comprobando la disponibilidá",
     "Has not responded to {organizerName}'s invitation yet" : "Nun respondió a la invitación de: {organizerName}",
     "Find a time" : "Atopar una hora",
     "with" : "con",
@@ -224,6 +225,8 @@ OC.L10N.register(
     "No match found" : "Nun s'atopó nenguna coincidencia",
     "Remove color" : "Quitar el color",
     "Event title" : "Títulu del eventu",
+    "From" : "De",
+    "To" : "Pa",
     "All day" : "Tol día",
     "Repeat" : "Repitir",
     "never" : "enxamás",
@@ -236,9 +239,9 @@ OC.L10N.register(
     "Suggestions" : "Suxerencies",
     "Has a projector" : "Tien proyeutor",
     "Has a whiteboard" : "Tien pizarra",
-    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} asientu","{seatingCapacity} asientos"],
     "Projector" : "Proyeutor",
     "Whiteboard" : "Pizarra",
+    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} asientu","{seatingCapacity} asientos"],
     "More details" : "Mas detalles",
     "Pick a date" : "Escueyi una data",
     "Please enter a valid date" : "Introduz una data válida",
@@ -248,9 +251,6 @@ OC.L10N.register(
     "An error occurred, unable to subscribe to calendar." : "Prodúxose un error, nun ye posible soscribise al calendariu.",
     "Time:" : "Hora:",
     "Personal" : "Personal",
-    "[Today]" : "[Güei]",
-    "[Tomorrow]" : "[Mañana]",
-    "[Yesterday]" : "[Ayeri]",
     "Event does not exist" : "L'eventu nun esiste",
     "Details" : "Detalles",
     "Invite" : "Convidar",
@@ -281,10 +281,14 @@ OC.L10N.register(
     "Error while sharing file" : "Hebo un error mentanto se compartía'l ficheru",
     "Error while sharing file with user" : "Hebo un error mentanto se compartía'l ficheru col usuariu",
     "An error occurred during getting file information" : "Prodúxose un error demientres se consiguía la información del ficheru",
-    "Chat room for event" : "Sala de charra pal eventu",
     "An error occurred, unable to delete the calendar." : "Prodúxose un error, nun ye posible desaniciar el calendariu",
     "Imported {filename}" : "Importóse «{filename}»",
     "This is an event reminder." : "Esto ye un recordatoriu del eventu.",
-    "User not found" : "Nun s'atopó l'usuariu"
+    "User not found" : "Nun s'atopó l'usuariu",
+    "You do not own this calendar, so you cannot add attendees to this event" : "Esti calendariu nun te pertenez, polo que nun pues amestar asistentes a esti eventu",
+    "[Today]" : "[Güei]",
+    "[Tomorrow]" : "[Mañana]",
+    "[Yesterday]" : "[Ayeri]",
+    "Chat room for event" : "Sala de charra pal eventu"
 },
 "nplurals=2; plural=(n != 1);");
