@@ -147,12 +147,12 @@ OC.L10N.register(
     "Custom color" : "Liv personelaet",
     "Special color of this event. Overrides the calendar-color." : "Liv dibar evit an darvoud-mañ. Diverkañ liv an deiziataer",
     "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr",
-    "Chat room for event" : "Sal-flapiñ evit un darvoud",
     "An error occurred, unable to delete the calendar." : "C'hoarvezet ez eus ur fazi, ne c'haller ket dilemel an deiziataer.",
     "Imported {filename}" : "Enporzhiet {filename}",
     "[Today]" : "[Hiziv]",
     "[Tomorrow]" : "[Warc'hoazh]",
     "[Yesterday]" : "[Dec'h]",
-    "Add a description" : "Ouzhpennañ un deskrivadur"
+    "Add a description" : "Ouzhpennañ un deskrivadur",
+    "Chat room for event" : "Sal-flapiñ evit un darvoud"
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
