@@ -7,9 +7,9 @@ OC.L10N.register(
     "Open »%s«" : "Ava »%s«",
     "Cheers!" : "Tervist!",
     "Upcoming events" : "Tulekul sündmused",
-    "More events" : "Rohkem sündmuseid",
     "No more events today" : "Täna rohkem sündmuseid pole",
     "No upcoming events" : "Tulekul sündmuseid pole",
+    "More events" : "Rohkem sündmuseid",
     "Calendar" : "Kalender",
     "Confirm" : "Kinnita",
     "Description:" : "Kirjeldus:",
@@ -36,10 +36,10 @@ OC.L10N.register(
     "Copy link" : "Kopeeri link",
     "Edit" : "Redigeeri",
     "Delete" : "Kustuta",
-    "Add new" : "Lisa uus",
     "Untitled calendar" : "Nimetu kalender",
     "Edit calendar" : "Muuda kalendrit",
     "Calendars" : "Kalendrid",
+    "Add new" : "Lisa uus",
     "New calendar" : "Uus kalender",
     "Export" : "Ekspordi",
     "Trash bin" : "Prügikast",
@@ -48,6 +48,7 @@ OC.L10N.register(
     "Restore" : "Taasta",
     "Delete permanently" : "Kustuta jäädavalt",
     "Empty trash bin" : "Tühjenda prügikast",
+    "Deck" : "Deck",
     "Hidden" : "Peidetud",
     "Internal link" : "Sisemine link",
     "Copy internal link" : "Kopeeri sisemine link",
@@ -114,12 +115,15 @@ OC.L10N.register(
     "Attachment {name} already exist!" : "Manus {name} on juba olemas!",
     "_{count} attachment_::_{count} attachments_" : ["{count} manus","{count} manust"],
     "Done" : "Valmis",
+    "Out of office" : "Kontorist väljas",
     "Unknown" : "Teadmata",
     "Accept" : "Nõustu",
     "Decline" : "Keeldu",
     "Tentative" : "Esialgne",
     "Attendees" : "Osalejad",
     "Remove group" : "Eemalda grupp",
+    "From" : "Saatja",
+    "To" : "Saaja",
     "All day" : "Kogu päev",
     "Repeat" : "Korda",
     "never" : "mitte kunagi",
@@ -130,6 +134,7 @@ OC.L10N.register(
     "Subscribe" : "Telli",
     "Personal" : "Isiklik",
     "Details" : "Üksikasjad",
+    "Invite" : "Kutse",
     "Resources" : "Ressursid",
     "Close" : "Sulge",
     "Anniversary" : "Aastapäev",
